@@ -8,7 +8,7 @@ else:
     import importlib_metadata
 
 from .core import run_validation
-from .dataclasses import (
+from .models import (
     Processor,
     ValidationStep,
     Validator,
